@@ -6,15 +6,15 @@
  *          Rodrigo Moya <rodrigo@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -1788,7 +1788,7 @@ remove_object_instance_cb (gpointer key, gpointer value, gpointer user_data)
 
 static ECalBackendSyncStatus
 e_cal_backend_file_modify_object (ECalBackendSync *backend, EDataCal *cal, const char *calobj, 
-				  CalObjModType mod, char **old_object)
+				  CalObjModType mod, char **old_object, char **new_object)
 {
 	RemoveRecurrenceData rrdata;
 	ECalBackendFile *cbfile;
@@ -1863,7 +1863,7 @@ e_cal_backend_file_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 			return GNOME_Evolution_Calendar_Success;
 		}
 
-		if (g_hash_table_lookup_extended (obj_data->recurrences, rid, &real_rid, &recurrence)) {
+		if (g_hash_table_lookup_extended (obj_data->recurrences, rid, (void **)&real_rid, (void **)&recurrence)) {
 			if (old_object)
 				*old_object = e_cal_component_get_as_string (recurrence);
 
@@ -1873,26 +1873,11 @@ e_cal_backend_file_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 			priv->comp = g_list_remove (priv->comp, recurrence);
 			obj_data->recurrences_list = g_list_remove (obj_data->recurrences_list, recurrence);
 			g_hash_table_remove (obj_data->recurrences, rid);
-		} else {
-			char *old, *new;
-
-			old = e_cal_component_get_as_string (obj_data->full_object);
-
-			new = e_cal_component_get_as_string (comp);
-			e_cal_backend_notify_object_modified (E_CAL_BACKEND (backend), old, new);
-
-			if (old_object)
-				*old_object = old;
-			else
-				g_free (old);
-			g_free (new);
 		}
 
 		/* add the detached instance */
-		icalcomponent_set_recurrenceid (e_cal_component_get_icalcomponent (comp),
-						icaltime_from_string (rid));
 		g_hash_table_insert (obj_data->recurrences, 
-				     g_strdup (e_cal_component_get_recurid_as_string (comp)),
+				     g_strdup (rid),
 				     comp);
 		icalcomponent_add_component (priv->icalcomp,
 					     e_cal_component_get_icalcomponent (comp));
@@ -1920,7 +1905,7 @@ e_cal_backend_file_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 
 		/* now deal with the detached recurrence */
 		if (g_hash_table_lookup_extended (obj_data->recurrences, rid,
-						  &real_rid, &recurrence)) {
+						  (void **)&real_rid, (void **)&recurrence)) {
 			if (old_object)
 				*old_object = e_cal_component_get_as_string (recurrence);
 
@@ -1985,7 +1970,7 @@ remove_instance (ECalBackendFile *cbfile, ECalBackendFileObject *obj_data, const
 	if (!rid || !*rid)
 		return;
 
-	if (g_hash_table_lookup_extended (obj_data->recurrences, rid, &hash_rid, &comp)) {
+	if (g_hash_table_lookup_extended (obj_data->recurrences, rid, (void **)&hash_rid, (void **)&comp)) {
 		/* remove the component from our data */
 		icalcomponent_remove_component (cbfile->priv->icalcomp,
 						e_cal_component_get_icalcomponent (comp));
@@ -2012,6 +1997,27 @@ remove_instance (ECalBackendFile *cbfile, ECalBackendFileObject *obj_data, const
 	cbfile->priv->comp = g_list_prepend (cbfile->priv->comp, obj_data->full_object);
 }
 
+static char *
+get_object_string_from_fileobject (ECalBackendFileObject *obj_data, const char *rid)
+{
+	ECalComponent *comp = obj_data->full_object;
+	char *real_rid;
+
+	if (!rid) {
+		return e_cal_component_get_as_string (comp);
+	} else {
+		if (g_hash_table_lookup_extended (obj_data->recurrences, rid, (void **)&real_rid, (void **)&comp))
+			return e_cal_component_get_as_string (comp);
+		else {
+			/* TODO remove this once we delete an instance from master object through
+			   modify request by setting exception */
+			return e_cal_component_get_as_string (comp);
+		}	
+	}
+
+	return NULL;
+}
+
 /* Remove_object handler for the file backend */
 static ECalBackendSyncStatus
 e_cal_backend_file_remove_object (ECalBackendSync *backend, EDataCal *cal,
@@ -2024,6 +2030,7 @@ e_cal_backend_file_remove_object (ECalBackendSync *backend, EDataCal *cal,
 	ECalBackendFileObject *obj_data;
 	ECalComponent *comp;
 	RemoveRecurrenceData rrdata;
+	const char *recur_id = NULL;
 
 	cbfile = E_CAL_BACKEND_FILE (backend);
 	priv = cbfile->priv;
@@ -2036,37 +2043,35 @@ e_cal_backend_file_remove_object (ECalBackendSync *backend, EDataCal *cal,
 	obj_data = g_hash_table_lookup (priv->comp_uid_hash, uid);
 	if (!obj_data)
 		return GNOME_Evolution_Calendar_ObjectNotFound;
-
+	
+	if (rid && *rid)
+		recur_id = rid;
+	
 	comp = obj_data->full_object;
 
 	switch (mod) {
 	case CALOBJ_MOD_ALL :
-		if (comp) {
-			*old_object = e_cal_component_get_as_string (comp);
-		} else {
-			char *real_rid;
-
-			if (g_hash_table_lookup_extended (obj_data->recurrences, rid, &real_rid, &comp))
-				*old_object = e_cal_component_get_as_string (comp);
-		}
-
+		*old_object = get_object_string_from_fileobject (obj_data, recur_id);
 		remove_component (cbfile, uid, obj_data);
 
 		*object = NULL;
 		break;
 	case CALOBJ_MOD_THIS :
-		*old_object = e_cal_component_get_as_string (comp);
-		if (!rid || !*rid) {
+		if (!recur_id) {
+			*old_object = get_object_string_from_fileobject (obj_data, recur_id);
 			remove_component (cbfile, uid, obj_data);
 			*object = NULL;
 		} else {
-			remove_instance (cbfile, obj_data, rid);
-			*object = e_cal_component_get_as_string (obj_data->full_object);
+			*old_object = get_object_string_from_fileobject (obj_data, recur_id);
+
+			remove_instance (cbfile, obj_data, recur_id);
+			if (comp)
+				*object = e_cal_component_get_as_string (comp);
 		}
 		break;
 	case CALOBJ_MOD_THISANDPRIOR :
 	case CALOBJ_MOD_THISANDFUTURE :
-		if (!rid || !*rid)
+		if (!recur_id || !*recur_id)
 			return GNOME_Evolution_Calendar_ObjectNotFound;
 
 		*old_object = e_cal_component_get_as_string (comp);
@@ -2077,12 +2082,12 @@ e_cal_backend_file_remove_object (ECalBackendSync *backend, EDataCal *cal,
 		priv->comp = g_list_remove (priv->comp, comp);
 
 		e_cal_util_remove_instances (e_cal_component_get_icalcomponent (comp),
-					     icaltime_from_string (rid), mod);
+					     icaltime_from_string (recur_id), mod);
 
 		/* now remove all detached instances */
 		rrdata.cbfile = cbfile;
 		rrdata.obj_data = obj_data;
-		rrdata.rid = rid;
+		rrdata.rid = recur_id;
 		rrdata.mod = mod;
 		g_hash_table_foreach_remove (obj_data->recurrences, (GHRFunc) remove_object_instance_cb, &rrdata);
 
