@@ -6,15 +6,15 @@
  * Authors: Rodrigo Moya <rodrigo@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -166,8 +166,12 @@ e_cal_backend_cache_constructor (GType type,
   
 	/* extract uid */
 	if (!g_ascii_strcasecmp ( g_param_spec_get_name (construct_properties->pspec), "uri")) {
+		char *cache_file;
+
 		uri = g_value_get_string (construct_properties->value);
-		g_object_set (obj, "filename", get_filename_from_uri (uri), NULL);
+		cache_file = get_filename_from_uri (uri);
+		g_object_set (obj, "filename", cache_file, NULL);
+		g_free (cache_file);
 	}
 
 	return obj;
@@ -318,6 +322,14 @@ e_cal_backend_cache_get_component (ECalBackendCache *cache, const char *uid, con
 
 /**
  * e_cal_backend_cache_put_component:
+ * @cache: An #ECalBackendCache object.
+ * @comp: Component to put on the cache.
+ *
+ * Puts the given calendar component in the given cache. This will add
+ * the component if it does not exist or replace it if there was a
+ * previous version of it.
+ *
+ * Return value: TRUE if the operation was successful, FALSE otherwise.
  */
 gboolean
 e_cal_backend_cache_put_component (ECalBackendCache *cache,
@@ -355,6 +367,14 @@ e_cal_backend_cache_put_component (ECalBackendCache *cache,
 
 /**
  * e_cal_backend_cache_remove_component:
+ * @cache: An #ECalBackendCache object.
+ * @uid: UID of the component to remove.
+ * @rid: Recurrence-ID of the component to remove. This is used when removing
+ * detached instances of a recurring appointment.
+ *
+ * Removes a component from the cache.
+ *
+ * Return value: TRUE if the component was removed, FALSE otherwise.
  */
 gboolean
 e_cal_backend_cache_remove_component (ECalBackendCache *cache,
@@ -382,6 +402,15 @@ e_cal_backend_cache_remove_component (ECalBackendCache *cache,
 	return retval;
 }
 
+/**
+ * e_cal_backend_cache_get_components:
+ * @cache: An #ECalBackendCache object.
+ *
+ * Retrieves a list of all the components stored in the cache.
+ *
+ * Return value: A list of all the components. Each item in the list is
+ * an #ECalComponent, which should be freed when no longer needed.
+ */
 GList *
 e_cal_backend_cache_get_components (ECalBackendCache *cache)
 {
@@ -422,6 +451,64 @@ e_cal_backend_cache_get_components (ECalBackendCache *cache)
         return list;
 }
 
+/**
+ * e_cal_backend_cache_get_components_by_uid:
+ * @cache: An #ECalBackendCache object.
+ * @uid: ID of the component to retrieve.
+ *
+ * Retrieves a ical components from the cache.
+ *
+ * Return value: The list of calendar components if found, or NULL otherwise.
+ */
+GSList *
+e_cal_backend_cache_get_components_by_uid (ECalBackendCache *cache, const char *uid)
+{
+        char *comp_str;
+        GSList *l;
+	GSList *list = NULL;
+	icalcomponent *icalcomp;
+	ECalComponent *comp = NULL;
+        
+        /* return null if cache is not a valid Backend Cache.  */
+	g_return_val_if_fail (E_IS_CAL_BACKEND_CACHE (cache), NULL);
+        l = e_file_cache_get_objects (E_FILE_CACHE (cache));
+        if (!l)
+                return NULL;
+        for ( ; l != NULL; l = g_slist_next (l)) {
+                comp_str = l->data;
+                if (comp_str) {
+                        icalcomp = icalparser_parse_string (comp_str);
+                        if (icalcomp) {
+				icalcomponent_kind kind;
+
+				kind = icalcomponent_isa (icalcomp);
+				if (kind == ICAL_VEVENT_COMPONENT || kind == ICAL_VTODO_COMPONENT) {
+					comp = e_cal_component_new ();
+					if ((e_cal_component_set_icalcomponent (comp, icalcomp)) &&
+						!strcmp (icalcomponent_get_uid (icalcomp), uid)) 
+							list = g_slist_append (list, comp);
+					else {
+						g_object_unref (comp);
+					}
+				} else
+					icalcomponent_free (icalcomp);
+                        }
+                }
+                
+        }
+
+        return list;
+}
+
+/**
+ * e_cal_backend_cache_get_timezone:
+ * @cache: An #ECalBackendCache object.
+ * @tzid: ID of the timezone to retrieve.
+ *
+ * Retrieves a timezone component from the cache.
+ *
+ * Return value: The timezone if found, or NULL otherwise.
+ */
 const icaltimezone *
 e_cal_backend_cache_get_timezone (ECalBackendCache *cache, const char *tzid)
 {
@@ -459,6 +546,16 @@ e_cal_backend_cache_get_timezone (ECalBackendCache *cache, const char *tzid)
 	return (const icaltimezone *) zone;
 }
 
+/**
+ * e_cal_backend_cache_put_timezone:
+ * @cache: An #ECalBackendCache object.
+ * @zone: The timezone to put on the cache.
+ *
+ * Puts the given timezone in the cache, adding it, if it did not exist, or
+ * replacing it, if there was an older version.
+ *
+ * Return value: TRUE if the timezone was put on the cache, FALSE otherwise.
+ */
 gboolean
 e_cal_backend_cache_put_timezone (ECalBackendCache *cache, const icaltimezone *zone)
 {
@@ -474,17 +571,17 @@ e_cal_backend_cache_put_timezone (ECalBackendCache *cache, const icaltimezone *z
 	priv = cache->priv;
 
 	/* add the timezone to the cache file */
-	icalcomp = icaltimezone_get_component (zone);
+	icalcomp = icaltimezone_get_component ((icaltimezone *)zone);
 	if (!icalcomp)
 		return FALSE;
 
-	if (e_file_cache_get_object (E_FILE_CACHE (cache), icaltimezone_get_tzid (zone))) {
+	if (e_file_cache_get_object (E_FILE_CACHE (cache), icaltimezone_get_tzid ((icaltimezone *)zone))) {
 		retval = e_file_cache_replace_object (E_FILE_CACHE (cache),
-						      icaltimezone_get_tzid (zone),
+						      icaltimezone_get_tzid ((icaltimezone *)zone),
 						      icalcomponent_as_ical_string (icalcomp));
 	} else {
 		retval = e_file_cache_add_object (E_FILE_CACHE (cache),
-						  icaltimezone_get_tzid (zone),
+						  icaltimezone_get_tzid ((icaltimezone *)zone),
 						  icalcomponent_as_ical_string (icalcomp));
 	}
 
@@ -492,7 +589,7 @@ e_cal_backend_cache_put_timezone (ECalBackendCache *cache, const icaltimezone *z
 		return FALSE;
 
 	/* check if the timezone already exists */
-	if (g_hash_table_lookup_extended (priv->timezones, icaltimezone_get_tzid (zone),
+	if (g_hash_table_lookup_extended (priv->timezones, icaltimezone_get_tzid ((icaltimezone *)zone),
 					  &orig_key, &orig_value)) {
 		/* remove the previous timezone */
 		g_hash_table_remove (priv->timezones, orig_key);
@@ -508,6 +605,15 @@ e_cal_backend_cache_put_timezone (ECalBackendCache *cache, const icaltimezone *z
 	return TRUE;
 }
 
+/**
+ * e_cal_backend_cache_put_default_timezone:
+ * @cache: An #ECalBackendCache object.
+ * @default_zone: The default timezone.
+ *
+ * Sets the default timezone on the cache.
+ *
+ * Return value: TRUE if the operation was successful, FALSE otherwise.
+ */
 gboolean
 e_cal_backend_cache_put_default_timezone (ECalBackendCache *cache, icaltimezone *default_zone)
 {
@@ -540,6 +646,15 @@ e_cal_backend_cache_put_default_timezone (ECalBackendCache *cache, icaltimezone
 
 }
 
+/**
+ * e_cal_backend_cache_get_default_timezone:
+ * @cache: An #ECalBackendCache object.
+ *
+ * Retrieves the default timezone from the cache.
+ *
+ * Return value: The default timezone, or NULL if no default timezone
+ * has been set on the cache.
+ */
 icaltimezone *
 e_cal_backend_cache_get_default_timezone (ECalBackendCache *cache)
 {
@@ -571,6 +686,15 @@ e_cal_backend_cache_get_default_timezone (ECalBackendCache *cache)
 	return NULL;
 }
 
+/**
+ * e_cal_backend_cache_remove_timezone:
+ * @cache: An #ECalBackendCache object.
+ * @tzid: ID of the timezone to remove.
+ *
+ * Removes a timezone component from the cache.
+ *
+ * Return value: TRUE if the timezone was removed, FALSE otherwise.
+ */
 gboolean
 e_cal_backend_cache_remove_timezone (ECalBackendCache *cache, const char *tzid)
 {
@@ -591,14 +715,29 @@ e_cal_backend_cache_remove_timezone (ECalBackendCache *cache, const char *tzid)
 	return e_file_cache_remove_object (E_FILE_CACHE (cache), tzid);
 }
 
+/**
+ * e_cal_backend_cache_get_keys:
+ * @cache: An #ECalBackendCache object.
+ *
+ * Gets the list of unique keys in the cache file.
+ *
+ * Return value: A list of all the keys. The items in the list are pointers
+ * to internal data, so should not be freed, only the list should.
+ */
 GSList *
 e_cal_backend_cache_get_keys (ECalBackendCache *cache)
 {
-        /* return null if cache is not a valid Backend Cache.  */
 	g_return_val_if_fail (E_IS_CAL_BACKEND_CACHE (cache), NULL);
         return e_file_cache_get_keys (E_FILE_CACHE (cache));
 }
 
+/**
+ * e_cal_backend_cache_set_marker:
+ * @cache: An #ECalBackendCache object.
+ *
+ * Marks the cache as populated, to discriminate between an empty calendar
+ * and an unpopulated one.
+ */
 void
 e_cal_backend_cache_set_marker (ECalBackendCache *cache)
 {
@@ -606,6 +745,15 @@ e_cal_backend_cache_set_marker (ECalBackendCache *cache)
 	e_file_cache_add_object (E_FILE_CACHE (cache), "populated", "TRUE");
 }
 
+/**
+ * e_cal_backend_cache_get_marker:
+ * @cache: An #ECalBackendCache object.
+ *
+ * Gets the marker of the cache. If this field is present, it means the
+ * cache has been populated.
+ *
+ * Return value: The value of the marker or NULL if the cache is still empty.
+ */
 const char *
 e_cal_backend_cache_get_marker (ECalBackendCache *cache)
 {
@@ -615,22 +763,32 @@ e_cal_backend_cache_get_marker (ECalBackendCache *cache)
 	return NULL;
 }
 
+/**
+ * e_cal_backend_cache_put_server_utc_time:
+ * @cache: An #ECalBackendCache object.
+ * @utc_str: UTC string.
+ *
+ * Return value: TRUE if the operation was successful, FALSE otherwise.
+ */
 gboolean
-e_cal_backend_cache_put_server_utc_time (ECalBackendCache *cache, char *utc_str)
+e_cal_backend_cache_put_server_utc_time (ECalBackendCache *cache, const char *utc_str)
 {
-	char *value;
 	gboolean ret_val = FALSE;
 	
 	g_return_val_if_fail (E_IS_CAL_BACKEND_CACHE (cache), FALSE);
 
-	value = g_strdup (utc_str);
-
-	if (!(ret_val = e_file_cache_add_object (E_FILE_CACHE (cache), "server_utc_time", value)))
-		ret_val = e_file_cache_replace_object (E_FILE_CACHE (cache), "server_utc_time", value);
+	if (!(ret_val = e_file_cache_add_object (E_FILE_CACHE (cache), "server_utc_time", utc_str)))
+		ret_val = e_file_cache_replace_object (E_FILE_CACHE (cache), "server_utc_time", utc_str);
 
 	return ret_val;
 }
 
+/**
+ * e_cal_backend_cache_get_server_utc_time:
+ * @cache: An #ECalBackendCache object.
+ *
+ * Return value: The server's UTC string.
+ */
 const char *
 e_cal_backend_cache_get_server_utc_time (ECalBackendCache *cache)
 {
@@ -639,3 +797,44 @@ e_cal_backend_cache_get_server_utc_time (ECalBackendCache *cache)
 	
        	return	e_file_cache_get_object (E_FILE_CACHE (cache), "server_utc_time");
 }
+
+/**
+ * e_cal_backend_cache_put_key_value:
+ * @cache: An #ECalBackendCache object.
+ * @keyp: The Key parameter to identify uniquely.
+ * @valuep: The value for the keyp parameter.
+ *
+ * Return value: TRUE if the operation was successful, FALSE otherwise.
+ */
+gboolean
+e_cal_backend_cache_put_key_value (ECalBackendCache *cache, const char *key, const char *value)
+{
+	gboolean ret_val = FALSE;
+	
+	g_return_val_if_fail (E_IS_CAL_BACKEND_CACHE (cache), FALSE);
+
+	if (value) {
+		e_file_cache_remove_object (E_FILE_CACHE (cache), key);
+		return TRUE;
+	}
+	
+	if (!(ret_val = e_file_cache_add_object (E_FILE_CACHE (cache), key, value)))
+		ret_val = e_file_cache_replace_object (E_FILE_CACHE (cache), key, value);
+
+	return ret_val;
+}
+
+/**
+ * e_cal_backend_cache_get_key_value:
+ * @cache: An #ECalBackendCache object.
+ *
+ * Return value: The value.
+ */
+const char *
+e_cal_backend_cache_get_key_value (ECalBackendCache *cache, const char *key)
+{
+
+	g_return_val_if_fail (E_IS_CAL_BACKEND_CACHE (cache), NULL);
+	
+       	return	e_file_cache_get_object (E_FILE_CACHE (cache), key);
+}
