@@ -2,7 +2,7 @@
   FILE: icalcomponent.c
   CREATOR: eric 28 April 1999
   
-  $Id: icalcomponent.c,v 1.27 2003/10/21 18:28:29 ettore Exp $
+  $Id: icalcomponent.c,v 1.27.32.1 2005/09/20 02:14:38 haip Exp $
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
 
@@ -1532,7 +1532,7 @@ icalcomponent_get_datetime(icalcomponent *comp, icalproperty *prop) {
 	}
 
 	if (tz == NULL)
-	    tz = icaltimezone_get_builtin_timezone(tzid);
+	    tz = icaltimezone_get_builtin_timezone_from_tzid(tzid);
 
 	if (tz != NULL)
 	    ret = icaltime_set_timezone(&ret, tz);
